---
name: Bug report / Feature request
about: 'Post a problem or idea'
title: ''
labels: ''
assignees: ''

---

<!-- A short summary of the issue, if appropriate -->


#### MCVE Code Sample
<!-- In order for the maintainers to efficiently understand and prioritize issues, we ask you post a "Minimal, Complete and Verifiable Example" (MCVE): http://matthewrocklin.com/blog/work/2018/02/28/minimal-bug-reports -->

```python
# Your code here

```

#### Expected Output


#### Problem Description
<!-- this should explain why the current behavior is a problem and why the expected output is a better solution -->


#### Versions

<details><summary>Output of `paidiverpy.show_versions()`</summary>

<!-- Paste the output here paidiverpy.show_versions() here -->


</details>
